#
# spec file for package python-rfc3986
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-rfc3986
Version:        2.0.0
Release:        2.5
Summary:        Python module for validating URI references per RFC 3986
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://rfc3986.rtfd.org
Source:         https://files.pythonhosted.org/packages/source/r/rfc3986/rfc3986-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A Python implementation of `RFC 3986`_ including validation and authority
parsing. Coming soon: `Reference Resolution <http://tools.ietf.org/html/rfc3986#section-5>`_.

%prep
%setup -q -n rfc3986-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst README.rst
%{python_sitelib}/*

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.0.0
  * Drop support for Python 2.7, 3.3, 3.4, 3.5, 3.6
  * Add support for Python 3.8, 3.9, 3.10
  * Fix bug in resolving URIs that only contain schemes which are valid per the RFC - bug 81
* Sun Jun  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  - Fix bug where a valid IRI is mishandled by ``urlparse`` and
  ``ParseResultBytes``.
  - Add :meth:`~rfc3986.builder.URIBuilder.extend_path`,
* Wed Apr 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.4.0
  * Prevent users from receiving an invalid authority parsed from
    a malicious URL.
  * Add from_uri to URIBuilder to allow creation of a URIBuilder
    from an existing URI.
* Fri May 17 2019 Hardik Italia <hitalia@suse.com>
- version update to 1.3.2
  * Remove unnecessary IRI-flavored matchers from rfc3986.misc to speed up
    import time on resource-constrained systems.
    See also `GitHub #55`_
* Mon May  6 2019 pgajdos@suse.com
- version update to 1.3.1
  * Only apply IDNA-encoding when there are characters
    outside of the ASCII character set.
    See also `GitHub #52`_
* Thu Apr 25 2019 pgajdos@suse.com
- version update to 1.3.0
  * Add the ``IRIReference`` class which parses data according
    to RFC 3987 and encodes into an ``URIReference``.
    See also `GitHub #50`_
- run tests
* Tue Mar  5 2019 Thomas Bechtold <tbechtold@suse.com>
- update to 1.2.0:
  * Update abnf_regexp.py
  * Update uri.py
  * Add test cases for 933d429f
  * Allow percent-encoded bytes in host
  * Remove unnecessary whitespace
  * Correct name throughout the project
  * Percent-encode %% chars
  * Minor tweak for cleaner logic
  * Add test cases specifically for %% detection
  * Make package building Windows-friendly
  * Tack on changes for #35
  * Drop Python 3.3, add Python 3.6 and 3.7
  * Update for new organization home
  * Bump version to 1.2.0
  * Use the encoding param in to_str and to_bytes
* Tue Dec 18 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Aug 10 2017 tbechtold@suse.com
- update to 1.1.0:
  * Bump version to 1.1.0
  * Fix theme setting for documentation
  * Exclude solitary line from coverage
  * Note the version we added Validator in
  * Fix documentation builds on RTD
  * Add check_validity_of to vaildator docs
  * Add some chars (!, =, etc) as allowed to the userinfo part of authority
  * Add release notes for v1.1.0
  * Add a separate testcase for special chars in userinfo and revert changes to other tests
  * Add validation to eliminate URIReference.is_valid
  * Add deprecation notices to old URIReference methods
  * Make tests fail: add "%%20!=" part to userinfo which is allowed as per RFC3986
- Convert to singlespec
* Sat Jun 10 2017 dmueller@suse.com
- update to 1.0.0:
  * Add support for :rfc:`6874` - Zone Identifiers in IPv6 Addresses
  * Add a more flexible and usable validation framework. See our documentation
    for more information.
  * Add an object to aid in building new URIs from scratch. See our
    documentation for more information.
  * Allow ``None`` to be used to eliminate components via ``copy_with`` for URIs
    and ParseResults.
* Wed Aug 31 2016 tbechtold@suse.com
- update to 0.4.1:
  - Normalize URIs constructed using ``ParseResult.from_parts`` and
    ``ParseResultBytes.from_parts``
  - Add ``ParseResult.from_parts`` and ``ParseResultBytes.from_parts`` class
    methods to easily create a ParseResult
  - When using regular expressions, use ``[0-9]`` instead of ``\d`` to avoid
    finding ports with "numerals" that are not valid in a port
  - Preserve empty query strings during normalization
  - Read README and HISTORY files using the appropriate codec so rfc3986 can be
    installed on systems with locale's other than utf-8 (specifically C)
  - Replace the standard library's urlparse behaviour
  - Update the regular name regular expression to accept all of the characters
    allowed in the RFC. Closes bug #11 (Thanks Viktor Haag). Previously URIs
    similar to "http://http-bin.org" would be considered invalid.
- Use pypi.io for Source url
* Fri Aug 29 2014 dmueller@suse.com
- Initial package (0.2.0)
